@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2022 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt for Python.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2022 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 
 #ifndef SBK_QT3DANIMATION_PYTHON_H
@@ -54,55 +18,36 @@
 
 // Bound library includes
 #include <Qt3DAnimation/qkeyframe.h>
-#include <Qt3DAnimation/qkeyframeanimation.h>
-#include <Qt3DAnimation/qblendedclipanimator.h>
-#include <Qt3DAnimation/qclipblendvalue.h>
-#include <Qt3DAnimation/qclock.h>
 #include <Qt3DAnimation/qabstractanimation.h>
-#include <Qt3DAnimation/qabstractchannelmapping.h>
-#include <Qt3DAnimation/qanimationaspect.h>
-#include <Qt3DAnimation/qchannelmapper.h>
-#include <Qt3DAnimation/qlerpclipblend.h>
 #include <Qt3DAnimation/qanimationcliploader.h>
-#include <Qt3DAnimation/qanimationgroup.h>
-#include <Qt3DAnimation/qanimationclipdata.h>
-#include <Qt3DAnimation/qanimationcontroller.h>
-#include <Qt3DAnimation/qabstractclipblendnode.h>
-#include <Qt3DAnimation/qabstractanimationclip.h>
 #include <Qt3DAnimation/qabstractclipanimator.h>
-#include <Qt3DAnimation/qanimationclip.h>
-#include <Qt3DAnimation/qchannel.h>
-#include <Qt3DAnimation/qchannelcomponent.h>
 #include <Qt3DAnimation/qanimationcallback.h>
-#include <Qt3DAnimation/qskeletonmapping.h>
-#include <Qt3DAnimation/qadditiveclipblend.h>
-#include <Qt3DAnimation/qchannelmapping.h>
-#include <Qt3DAnimation/qmorphtarget.h>
-#include <Qt3DAnimation/qvertexblendanimation.h>
-#include <Qt3DAnimation/qclipanimator.h>
 #include <Qt3DAnimation/qmorphinganimation.h>
-// Conversion Includes - Primitive Types
-#include <QAnyStringView>
-#include <QString>
-#include <QStringList>
-#include <QStringView>
-
-// Conversion Includes - Container Types
-#include <pysideqflags.h>
-#include <QList>
-#include <QMap>
-#include <pysideqflags.h>
-#include <QMultiMap>
-#include <QPair>
-#include <QQueue>
-#include <QSet>
-#include <QStack>
-#include <list>
-#include <map>
-#include <utility>
-#include <unordered_map>
-#include <vector>
+#include <Qt3DAnimation/qkeyframeanimation.h>
 
+namespace Qt3DAnimation {
+    class QAbstractAnimationClip;
+    class QAbstractChannelMapping;
+    class QAbstractClipBlendNode;
+    class QAdditiveClipBlend;
+    class QAnimationAspect;
+    class QAnimationClip;
+    class QAnimationClipData;
+    class QAnimationController;
+    class QAnimationGroup;
+    class QBlendedClipAnimator;
+    class QChannel;
+    class QChannelComponent;
+    class QChannelMapper;
+    class QChannelMapping;
+    class QClipAnimator;
+    class QClipBlendValue;
+    class QClock;
+    class QLerpClipBlend;
+    class QMorphTarget;
+    class QSkeletonMapping;
+    class QVertexBlendAnimation;
+}
 // Type indices
 enum : int {
     SBK_Qt3DAnimationQT3DANIMATION_IDX                       = 0,
