@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2022 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt for Python.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2022 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 
 #ifndef SBK_QT3DCORE_PYTHON_H
@@ -52,48 +16,32 @@
 
 // Bound library includes
 #include <Qt3DCore/qbackendnode.h>
-#include <Qt3DCore/qaspectjob.h>
-#include <Qt3DCore/qcoresettings.h>
-#include <Qt3DCore/qgeometry.h>
-#include <Qt3DCore/qabstractaspect.h>
-#include <Qt3DCore/qarmature.h>
-#include <Qt3DCore/qtransform.h>
 #include <Qt3DCore/qnodeid.h>
-#include <Qt3DCore/qnode.h>
-#include <Qt3DCore/qentity.h>
-#include <Qt3DCore/qskeleton.h>
-#include <Qt3DCore/qskeletonloader.h>
 #include <Qt3DCore/qgeometryview.h>
 #include <Qt3DCore/qbuffer.h>
-#include <Qt3DCore/qcomponent.h>
+#include <Qt3DCore/qskeletonloader.h>
 #include <Qt3DCore/qattribute.h>
-#include <Qt3DCore/qboundingvolume.h>
-#include <Qt3DCore/qjoint.h>
 #include <Qt3DCore/qaspectengine.h>
-#include <Qt3DCore/qabstractfunctor.h>
-#include <Qt3DCore/qabstractskeleton.h>
-// Conversion Includes - Primitive Types
-#include <QAnyStringView>
-#include <QString>
-#include <QStringList>
-#include <QStringView>
-
-// Conversion Includes - Container Types
-#include <pysideqflags.h>
-#include <QList>
-#include <QMap>
-#include <pysideqflags.h>
-#include <QMultiMap>
-#include <QPair>
-#include <QQueue>
-#include <QSet>
-#include <QStack>
-#include <list>
-#include <map>
-#include <utility>
-#include <unordered_map>
-#include <vector>
 
+namespace Qt3DCore {
+    class QAbstractAspect;
+    class QAbstractFunctor;
+    class QAbstractSkeleton;
+    class QArmature;
+    class QAspectJob;
+    class QBackendNodeMapper;
+    class QBoundingVolume;
+    class QComponent;
+    class QCoreSettings;
+    class QEntity;
+    class QGeometry;
+    class QJoint;
+    class QNode;
+    class QNodeId;
+    struct QNodeIdTypePair;
+    class QSkeleton;
+    class QTransform;
+}
 // Type indices
 enum : int {
     SBK_Qt3DCoreQT3DCORE_IDX                                 = 0,
