@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2022 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt for Python.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2022 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 
 #ifndef SBK_QT3DRENDER_PYTHON_H
@@ -54,127 +18,122 @@
 // Bound library includes
 #include <Qt3DRender/qblitframebuffer.h>
 #include <Qt3DRender/qabstracttexture.h>
-#include <Qt3DRender/qproximityfilter.h>
+#include <Qt3DRender/qrendertargetoutput.h>
 #include <Qt3DRender/qlayerfilter.h>
 #include <Qt3DRender/qsubtreeenabler.h>
 #include <Qt3DRender/qpickingsettings.h>
-#include <Qt3DRender/qclearbuffers.h>
-#include <Qt3DRender/qenvironmentlight.h>
-#include <Qt3DRender/qrendercapture.h>
-#include <Qt3DRender/qviewport.h>
-#include <Qt3DRender/qstenciltestarguments.h>
-#include <Qt3DRender/qrenderpassfilter.h>
-#include <Qt3DRender/qstenciloperation.h>
-#include <Qt3DRender/qraycaster.h>
-#include <Qt3DRender/qcullface.h>
-#include <Qt3DRender/qpickevent.h>
-#include <Qt3DRender/qdepthrange.h>
-#include <Qt3DRender/qsceneloader.h>
-#include <Qt3DRender/qgraphicsapifilter.h>
-#include <Qt3DRender/qobjectpicker.h>
-#include <Qt3DRender/qpicklineevent.h>
-#include <Qt3DRender/qscreenraycaster.h>
-#include <Qt3DRender/qalphacoverage.h>
-#include <Qt3DRender/qtexture.h>
-#include <Qt3DRender/qcamera.h>
-#include <Qt3DRender/qdithering.h>
-#include <Qt3DRender/qmesh.h>
-#include <Qt3DRender/qalphatest.h>
-#include <Qt3DRender/qnodepthmask.h>
-#include <Qt3DRender/qspotlight.h>
-#include <Qt3DRender/qlevelofdetail.h>
-#include <Qt3DRender/qpicktriangleevent.h>
-#include <Qt3DRender/qsortpolicy.h>
-#include <Qt3DRender/qdirectionallight.h>
-#include <Qt3DRender/qrendercapabilities.h>
-#include <Qt3DRender/qpolygonoffset.h>
-#include <Qt3DRender/qfrustumculling.h>
-#include <Qt3DRender/qpickpointevent.h>
-#include <Qt3DRender/qclipplane.h>
-#include <Qt3DRender/qshaderdata.h>
-#include <Qt3DRender/qstencilmask.h>
-#include <Qt3DRender/qpaintedtextureimage.h>
-#include <Qt3DRender/qrendertargetoutput.h>
-#include <Qt3DRender/qbuffercapture.h>
-#include <Qt3DRender/qframegraphnode.h>
 #include <Qt3DRender/qcomputecommand.h>
-#include <Qt3DRender/qmultisampleantialiasing.h>
-#include <Qt3DRender/qcolormask.h>
-#include <Qt3DRender/qrendertarget.h>
-#include <Qt3DRender/qscissortest.h>
+#include <Qt3DRender/qclearbuffers.h>
 #include <Qt3DRender/qabstractlight.h>
 #include <Qt3DRender/qfrontface.h>
 #include <Qt3DRender/qtexturewrapmode.h>
-#include <Qt3DRender/qseamlesscubemap.h>
-#include <Qt3DRender/qcameraselector.h>
-#include <Qt3DRender/qdepthtest.h>
 #include <Qt3DRender/qpointsize.h>
+#include <Qt3DRender/qdepthtest.h>
 #include <Qt3DRender/qsetfence.h>
 #include <Qt3DRender/qstenciloperationarguments.h>
-#include <Qt3DRender/qtechnique.h>
-#include <Qt3DRender/qfilterkey.h>
-#include <Qt3DRender/qtextureimagedata.h>
-#include <Qt3DRender/qrenderstateset.h>
-#include <Qt3DRender/qpickingproxy.h>
+#include <Qt3DRender/qstenciltestarguments.h>
 #include <Qt3DRender/qshaderprogram.h>
+#include <Qt3DRender/qcullface.h>
 #include <Qt3DRender/qwaitfence.h>
+#include <Qt3DRender/qpickevent.h>
 #include <Qt3DRender/qtextureimage.h>
-#include <Qt3DRender/qlayer.h>
-#include <Qt3DRender/qlevelofdetailswitch.h>
+#include <Qt3DRender/qsceneloader.h>
+#include <Qt3DRender/qgraphicsapifilter.h>
 #include <Qt3DRender/qshaderimage.h>
-#include <Qt3DRender/qshaderprogrambuilder.h>
 #include <Qt3DRender/qrendersettings.h>
 #include <Qt3DRender/qabstractraycaster.h>
 #include <Qt3DRender/qblendequationarguments.h>
-#include <Qt3DRender/qtexturedataupdate.h>
-#include <Qt3DRender/qtechniquefilter.h>
-#include <Qt3DRender/qpointlight.h>
+#include <Qt3DRender/qcamera.h>
+#include <Qt3DRender/qmesh.h>
+#include <Qt3DRender/qalphatest.h>
+#include <Qt3DRender/qlevelofdetail.h>
 #include <Qt3DRender/qgeometryrenderer.h>
-#include <Qt3DRender/qrenderpass.h>
+#include <Qt3DRender/qsortpolicy.h>
 #include <Qt3DRender/qblendequation.h>
 #include <Qt3DRender/qrenderaspect.h>
+#include <Qt3DRender/qrendercapabilities.h>
 #include <Qt3DRender/qrenderapi.h>
-#include <Qt3DRender/qmaterial.h>
-#include <Qt3DRender/qtextureimagedatagenerator.h>
 #include <Qt3DRender/qcameralens.h>
-#include <Qt3DRender/qrendersurfaceselector.h>
-#include <Qt3DRender/qlinewidth.h>
-#include <Qt3DRender/qabstracttextureimage.h>
 #include <Qt3DRender/qraycasterhit.h>
-#include <Qt3DRender/qnopicking.h>
 #include <Qt3DRender/qrastermode.h>
-#include <Qt3DRender/qdispatchcompute.h>
-#include <Qt3DRender/qlevelofdetailboundingsphere.h>
 #include <Qt3DRender/qmemorybarrier.h>
-#include <Qt3DRender/qtexturedata.h>
-#include <Qt3DRender/qparameter.h>
-#include <Qt3DRender/qrendertargetselector.h>
-#include <Qt3DRender/qstenciltest.h>
-#include <Qt3DRender/qnodraw.h>
-#include <Qt3DRender/qrenderstate.h>
-#include <Qt3DRender/qeffect.h>
-// Conversion Includes - Primitive Types
-#include <QAnyStringView>
-#include <QString>
-#include <QStringList>
-#include <QStringView>
-
-// Conversion Includes - Container Types
-#include <pysideqflags.h>
-#include <QList>
-#include <QMap>
-#include <pysideqflags.h>
-#include <QMultiMap>
-#include <QPair>
-#include <QQueue>
-#include <QSet>
-#include <QStack>
-#include <list>
-#include <map>
-#include <utility>
-#include <unordered_map>
-#include <vector>
 
+namespace Qt3DRender {
+    class PropertyReaderInterface;
+    class QAbstractTextureImage;
+    class QAlphaCoverage;
+    class QBufferCapture;
+    class QCameraSelector;
+    class QClipPlane;
+    class QColorMask;
+    class QDepthRange;
+    class QDirectionalLight;
+    class QDispatchCompute;
+    class QDithering;
+    class QEffect;
+    class QEnvironmentLight;
+    class QFilterKey;
+    class QFrameGraphNode;
+    class QFrustumCulling;
+    class QLayer;
+    class QLevelOfDetailBoundingSphere;
+    class QLevelOfDetailSwitch;
+    class QLineWidth;
+    class QMaterial;
+    class QMultiSampleAntiAliasing;
+    class QNoDepthMask;
+    class QNoDraw;
+    class QNoPicking;
+    class QObjectPicker;
+    class QPaintedTextureImage;
+    class QParameter;
+    class QPickLineEvent;
+    class QPickPointEvent;
+    class QPickTriangleEvent;
+    class QPickingProxy;
+    class QPointLight;
+    class QPolygonOffset;
+    class QProximityFilter;
+    class QRayCaster;
+    class QRenderCapture;
+    class QRenderCaptureReply;
+    class QRenderPass;
+    class QRenderPassFilter;
+    class QRenderState;
+    class QRenderStateSet;
+    class QRenderSurfaceSelector;
+    class QRenderTarget;
+    class QRenderTargetSelector;
+    class QScissorTest;
+    class QScreenRayCaster;
+    class QSeamlessCubemap;
+    class QShaderData;
+    class QShaderProgramBuilder;
+    class QSharedGLTexture;
+    class QSpotLight;
+    class QStencilMask;
+    class QStencilOperation;
+    class QStencilTest;
+    class QTechnique;
+    class QTechniqueFilter;
+    class QTexture1D;
+    class QTexture1DArray;
+    class QTexture2D;
+    class QTexture2DArray;
+    class QTexture2DMultisample;
+    class QTexture2DMultisampleArray;
+    class QTexture3D;
+    class QTextureBuffer;
+    class QTextureCubeMap;
+    class QTextureCubeMapArray;
+    class QTextureData;
+    class QTextureDataUpdate;
+    class QTextureImageData;
+    class QTextureImageDataGenerator;
+    class QTextureLoader;
+    class QTextureRectangle;
+    class QViewport;
+}
 // Type indices
 enum : int {
     SBK_QT3DRENDER_API_IDX                                   = 3,
