@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2022 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt for Python.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2022 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 
 #ifndef SBK_QTCHARTS_PYTHON_H
@@ -52,81 +16,59 @@
 #include <pyside6_qtcore_python.h>
 
 // Bound library includes
-#include <QtCharts/qhbarmodelmapper.h>
-#include <QtCharts/qvcandlestickmodelmapper.h>
-#include <QtCharts/qvxymodelmapper.h>
-#include <QtCharts/qboxplotmodelmapper.h>
-#include <QtCharts/qhorizontalstackedbarseries.h>
-#include <QtCharts/qhorizontalbarseries.h>
 #include <QtCharts/qvalueaxis.h>
 #include <QtCharts/qabstractbarseries.h>
 #include <QtCharts/qpolarchart.h>
-#include <QtCharts/qbarlegendmarker.h>
-#include <QtCharts/qcandlestickmodelmapper.h>
 #include <QtCharts/qpieslice.h>
-#include <QtCharts/qsplineseries.h>
-#include <QtCharts/qxylegendmarker.h>
 #include <pyside_numpy.h>
 #include <QtCharts/qchart.h>
-#include <QtCharts/qpieseries.h>
-#include <QtCharts/qhpiemodelmapper.h>
-#include <QtCharts/qlogvalueaxis.h>
-#include <QtCharts/qvbarmodelmapper.h>
-#include <QtCharts/qpielegendmarker.h>
-#include <QtCharts/qareaseries.h>
-#include <QtCharts/qvpiemodelmapper.h>
 #include <QtCharts/qxyseries.h>
 #include <QtCharts/qboxset.h>
 #include <QtCharts/qchartview.h>
-#include <QtCharts/qvboxplotmodelmapper.h>
-#include <QtCharts/qbarseries.h>
-#include <QtCharts/qdatetimeaxis.h>
 #include <QtCharts/qabstractseries.h>
-#include <QtCharts/qpercentbarseries.h>
-#include <QtCharts/qstackedbarseries.h>
-#include <QtCharts/qcandlestickseries.h>
-#include <QtCharts/qcandlestickset.h>
-#include <QtCharts/qcandlesticklegendmarker.h>
 #include <QtCharts/qlegend.h>
 #include <QtCharts/qabstractaxis.h>
-#include <QtCharts/qbarset.h>
-#include <QtCharts/qboxplotlegendmarker.h>
-#include <QtCharts/qarealegendmarker.h>
-#include <QtCharts/qbarcategoryaxis.h>
-#include <QtCharts/qboxplotseries.h>
-#include <QtCharts/qbarmodelmapper.h>
 #include <QtCharts/qscatterseries.h>
-#include <QtCharts/qhboxplotmodelmapper.h>
 #include <QtCharts/qlegendmarker.h>
-#include <QtCharts/qpiemodelmapper.h>
-#include <QtCharts/qxymodelmapper.h>
 #include <QtCharts/qcategoryaxis.h>
-#include <QtCharts/qhxymodelmapper.h>
-#include <QtCharts/qhcandlestickmodelmapper.h>
-#include <QtCharts/qhorizontalpercentbarseries.h>
-#include <QtCharts/qlineseries.h>
-// Conversion Includes - Primitive Types
-#include <QAnyStringView>
-#include <QString>
-#include <QStringList>
-#include <QStringView>
-
-// Conversion Includes - Container Types
-#include <pysideqflags.h>
-#include <QList>
-#include <QMap>
-#include <pysideqflags.h>
-#include <QMultiMap>
-#include <QPair>
-#include <QQueue>
-#include <QSet>
-#include <QStack>
-#include <list>
-#include <map>
-#include <utility>
-#include <unordered_map>
-#include <vector>
-
+class QAreaLegendMarker;
+class QAreaSeries;
+class QBarCategoryAxis;
+class QBarLegendMarker;
+class QBarModelMapper;
+class QBarSeries;
+class QBarSet;
+class QBoxPlotLegendMarker;
+class QBoxPlotModelMapper;
+class QBoxPlotSeries;
+class QCandlestickLegendMarker;
+class QCandlestickModelMapper;
+class QCandlestickSeries;
+class QCandlestickSet;
+class QDateTimeAxis;
+class QHBarModelMapper;
+class QHBoxPlotModelMapper;
+class QHCandlestickModelMapper;
+class QHPieModelMapper;
+class QHXYModelMapper;
+class QHorizontalBarSeries;
+class QHorizontalPercentBarSeries;
+class QHorizontalStackedBarSeries;
+class QLineSeries;
+class QLogValueAxis;
+class QPercentBarSeries;
+class QPieLegendMarker;
+class QPieModelMapper;
+class QPieSeries;
+class QSplineSeries;
+class QStackedBarSeries;
+class QVBarModelMapper;
+class QVBoxPlotModelMapper;
+class QVCandlestickModelMapper;
+class QVPieModelMapper;
+class QVXYModelMapper;
+class QXYLegendMarker;
+class QXYModelMapper;
 // Type indices
 enum : int {
     SBK_QABSTRACTAXIS_AXISTYPE_IDX                           = 1,
