@@ -19,28 +19,6 @@
 #include <QtCore/qfuture.h>
 #include <QtConcurrent/qtconcurrentthreadengine.h>
 #include <QtCore/qfuturewatcher.h>
-// Conversion Includes - Primitive Types
-#include <QAnyStringView>
-#include <QString>
-#include <QStringList>
-#include <QStringView>
-
-// Conversion Includes - Container Types
-#include <pysideqflags.h>
-#include <QList>
-#include <QMap>
-#include <pysideqflags.h>
-#include <QMultiMap>
-#include <QPair>
-#include <QQueue>
-#include <QSet>
-#include <QStack>
-#include <list>
-#include <map>
-#include <utility>
-#include <unordered_map>
-#include <vector>
-
 // Type indices
 enum : int {
     SBK_QFUTUREQSTRING_IDX                                   = 1,
