@@ -15,65 +15,41 @@
 #include <pyside6_qtcore_python.h>
 
 // Bound library includes
-#include <QtDataVisualization/qsurfacedataproxy.h>
-#include <QtDataVisualization/qbardataitem.h>
 #include <QtDataVisualization/qsurface3dseries.h>
 #include <QtDataVisualization/qitemmodelbardataproxy.h>
-#include <QtDataVisualization/qcustom3ditem.h>
-#include <QtDataVisualization/qitemmodelscatterdataproxy.h>
-#include <QtDataVisualization/q3dscatter.h>
 #include <QtDataVisualization/qabstract3dseries.h>
-#include <QtDataVisualization/q3dscene.h>
-#include <QtDataVisualization/qcustom3dvolume.h>
 #include <QtDataVisualization/qitemmodelsurfacedataproxy.h>
-#include <QtDataVisualization/qscatterdataitem.h>
-#include <QtDataVisualization/q3dsurface.h>
 #include <QtDataVisualization/q3dcamera.h>
-#include <QtDataVisualization/qbardataproxy.h>
-#include <QtDataVisualization/qvalue3daxis.h>
-#include <QtDataVisualization/qvalue3daxisformatter.h>
-#include <QtDataVisualization/q3dinputhandler.h>
-#include <QtDataVisualization/q3dlight.h>
 #include <QtDataVisualization/qabstract3daxis.h>
-#include <QtDataVisualization/qcustom3dlabel.h>
-#include <QtDataVisualization/qtouch3dinputhandler.h>
-#include <QtDataVisualization/qheightmapsurfacedataproxy.h>
-#include <QtDataVisualization/qscatterdataproxy.h>
-#include <QtDataVisualization/qbar3dseries.h>
 #include <QtDataVisualization/qabstract3dinputhandler.h>
 #include <QtDataVisualization/qabstract3dgraph.h>
-#include <QtDataVisualization/qcategory3daxis.h>
 #include <QtDataVisualization/q3dtheme.h>
 #include <QtDataVisualization/qabstractdataproxy.h>
-#include <QtDataVisualization/qscatter3dseries.h>
-#include <QtDataVisualization/qsurfacedataitem.h>
-#include <QtDataVisualization/q3dobject.h>
-#include <QtDataVisualization/qlogvalue3daxisformatter.h>
-#include <QtDataVisualization/q3dbars.h>
-// Conversion Includes - Primitive Types
-#include <QAnyStringView>
-#include <qbardataproxy.h>
-#include <QString>
-#include <QStringList>
-#include <QStringView>
-#include <qsurfacedataproxy.h>
-
-// Conversion Includes - Container Types
-#include <pysideqflags.h>
-#include <QList>
-#include <QMap>
-#include <pysideqflags.h>
-#include <QMultiMap>
-#include <QPair>
-#include <QQueue>
-#include <QSet>
-#include <QStack>
-#include <list>
-#include <map>
-#include <utility>
-#include <unordered_map>
-#include <vector>
-
+class Q3DBars;
+class Q3DInputHandler;
+class Q3DLight;
+class Q3DObject;
+class Q3DScatter;
+class Q3DScene;
+class Q3DSurface;
+class QBar3DSeries;
+class QBarDataItem;
+class QBarDataProxy;
+class QCategory3DAxis;
+class QCustom3DItem;
+class QCustom3DLabel;
+class QCustom3DVolume;
+class QHeightMapSurfaceDataProxy;
+class QItemModelScatterDataProxy;
+class QLogValue3DAxisFormatter;
+class QScatter3DSeries;
+class QScatterDataItem;
+class QScatterDataProxy;
+class QSurfaceDataItem;
+class QSurfaceDataProxy;
+class QTouch3DInputHandler;
+class QValue3DAxis;
+class QValue3DAxisFormatter;
 // Type indices
 enum : int {
     SBK_Q3DBARS_IDX                                          = 0,
