@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2022 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt for Python.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2022 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 
 #ifndef SBK_QTDESIGNER_PYTHON_H
@@ -53,49 +17,33 @@
 
 // Bound library includes
 #include <QtDesigner/abstractformwindowmanager.h>
-#include <QtDesigner/abstractobjectinspector.h>
-#include <QtUiPlugin/customwidget.h>
 #include <QtDesigner/abstractformwindowcursor.h>
-#include <QtDesigner/propertysheet.h>
-#include <QtDesigner/taskmenu.h>
-#include <QtDesigner/formbuilder.h>
-#include <QtDesigner/default_extensionfactory.h>
 #include <QtDesigner/abstractformwindow.h>
-#include <QtDesigner/dynamicpropertysheet.h>
-#include <QtDesigner/abstractformeditor.h>
-#include <QtDesigner/abstractformbuilder.h>
-#include <QtDesigner/container.h>
-#include <QtDesigner/abstractpropertyeditor.h>
 #include <QtDesigner/abstractwidgetbox.h>
-#include <QtDesigner/extension.h>
-#include <QtDesigner/qextensionmanager.h>
-#include <QtDesigner/abstractactioneditor.h>
 #include <QtDesigner/abstractdnditem.h>
-#include <QtDesigner/membersheet.h>
-#include <qpydesignerextensions.h>
-#include <QtDesigner/abstractformwindowtool.h>
-// Conversion Includes - Primitive Types
-#include <QAnyStringView>
-#include <QString>
-#include <QStringList>
-#include <QStringView>
-
-// Conversion Includes - Container Types
-#include <pysideqflags.h>
-#include <QList>
-#include <QMap>
-#include <pysideqflags.h>
-#include <QMultiMap>
-#include <QPair>
-#include <QQueue>
-#include <QSet>
-#include <QStack>
-#include <list>
-#include <map>
-#include <utility>
-#include <unordered_map>
-#include <vector>
-
+class QAbstractExtensionFactory;
+class QAbstractExtensionManager;
+class QAbstractFormBuilder;
+class QDesignerActionEditorInterface;
+class QDesignerContainerExtension;
+class QDesignerCustomWidgetCollectionInterface;
+class QDesignerCustomWidgetInterface;
+class QDesignerDynamicPropertySheetExtension;
+class QDesignerFormEditorInterface;
+class QDesignerFormWindowToolInterface;
+class QDesignerMemberSheetExtension;
+class QDesignerObjectInspectorInterface;
+class QDesignerPropertyEditorInterface;
+class QDesignerPropertySheetExtension;
+class QDesignerTaskMenuExtension;
+class QExtensionFactory;
+class QExtensionManager;
+class QFormBuilder;
+class QPyDesignerContainerExtension;
+class QPyDesignerCustomWidgetCollection;
+class QPyDesignerMemberSheetExtension;
+class QPyDesignerPropertySheetExtension;
+class QPyDesignerTaskMenuExtension;
 // Type indices
 enum : int {
     SBK_QABSTRACTEXTENSIONFACTORY_IDX                        = 0,
