@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2022 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt for Python.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2022 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 
 #ifndef SBK_QTGUI_PYTHON_H
@@ -57,13 +21,7 @@
 #include <QtGui/qvalidator.h>
 #include <QtGui/qpaintengine.h>
 #include <QtGui/qeventpoint.h>
-#include <QtGui/qdesktopservices.h>
-#include <QtGui/qpixmap.h>
-#include <QtGui/qbackingstore.h>
 #include <QtGui/qcolor.h>
-#include <QtGui/qpen.h>
-#include <QtGui/qtexttable.h>
-#include <QtGui/qcolortransform.h>
 #include <QtGui/qimageiohandler.h>
 #include <QtGui/qinputmethod.h>
 #include <QtGui/qimagewriter.h>
@@ -71,72 +29,47 @@
 #include <QtGui/qstandarditemmodel.h>
 #include <QPainterPath>
 #include <QtGui/qtextformat.h>
+#include <QtGui/qaccessible_base.h>
 #include <QtGui/qrgba64.h>
-#include <QtGui/qbitmap.h>
 #include <QtGui/qimage.h>
-#include <QtGui/qtextdocumentwriter.h>
-#include <QtGui/qvectornd.h>
 #include <QtGui/qpixelformat.h>
-#include <QtGui/qstylehints.h>
-#include <QtGui/qundostack.h>
 #include <QtGui/qmatrix4x4.h>
-#include <QtGui/qpaintdevicewindow.h>
 #include <QtGui/qinputdevice.h>
 #include <QtGui/qgenericmatrix.h>
 #include <QtGui/qaction.h>
 #include <QPainter>
 #include <QtGui/qpainter.h>
-#include <QtGui/qrasterwindow.h>
 #include <QtGui/qsessionmanager.h>
 #include <QtGui/qrawfont.h>
 #include <QTextLayout>
 #include <QtGui/qkeysequence.h>
 #include <QtGui/qpagelayout.h>
-#include <QtGui/qabstracttextdocumentlayout.h>
 #include <QtGui/qcolorspace.h>
-#include <QtGui/qpicture.h>
-#include <QtGui/qquaternion.h>
-#include <QtGui/qtextdocumentfragment.h>
-#include <QtGui/qsyntaxhighlighter.h>
+#include <QtGui/qabstracttextdocumentlayout.h>
 #include <QtGui/qsurface.h>
-#include <QtGui/qopenglextrafunctions.h>
-#include <qpytextobject.h>
 #include <QtGui/qtextdocument.h>
 #include <QtGui/qtextlayout.h>
-#include <QtGui/qfontmetrics.h>
 #include <QtGui/qpainterpath.h>
 #include <QtGui/qpointingdevice.h>
-#include <QtGui/qdrag.h>
 #include <QtGui/qwindow.h>
 #include <QtGui/qpixmapcache.h>
 #include <QTextFrame>
-#include <QtGui/qoffscreensurface.h>
 #include <QtGui/qsurfaceformat.h>
 #include <QtGui/qopenglcontext.h>
 #include <QtGui/qpalette.h>
-#include <qtguihelper.h>
 #include <QtGui/qtextcursor.h>
 #include <QtGui/qactiongroup.h>
-#include <QtGui/qpolygon.h>
 #include <QtGui/qregion.h>
-#include <QtGui/qpdfwriter.h>
 #include <QtGui/qfontdatabase.h>
-#include <QtGui/qscreen.h>
-#include <QtGui/qundogroup.h>
 #include <QtGui/qpageranges.h>
-#include <QtGui/qcursor.h>
 #include <QtGui/qpaintdevice.h>
-#include <QtGui/qfontinfo.h>
 #include <QtGui/qiconengine.h>
 #include <QTextBlock>
 #include <QtGui/qaccessible.h>
 #include <QtGui/qfont.h>
 #include <QtGui/qbrush.h>
-#include <QtGui/qguiapplication.h>
 #include <QtGui/qtextoption.h>
-#include <QtGui/qtextlist.h>
 #include <QtGui/qpagedpaintdevice.h>
-#include <QtGui/qshortcut.h>
 #include <QtGui/qtextobject.h>
 #include <QtGui/qglyphrun.h>
 #include <QtGui/qpagesize.h>
@@ -146,29 +79,116 @@
 #include <QtGui/qicon.h>
 #include <QtGui/qabstractfileiconprovider.h>
 #include <QtGui/qimagereader.h>
-#include <QtGui/qaccessibleobject.h>
-// Conversion Includes - Primitive Types
-#include <QAnyStringView>
-#include <QString>
-#include <QStringList>
-#include <QStringView>
-
-// Conversion Includes - Container Types
-#include <pysideqflags.h>
-#include <QList>
-#include <QMap>
-#include <pysideqflags.h>
-#include <QMultiMap>
-#include <QPair>
-#include <QQueue>
-#include <QSet>
-#include <QStack>
-#include <list>
-#include <map>
-#include <utility>
-#include <unordered_map>
-#include <vector>
+class QAccessibleActionInterface;
+class QAccessibleEditableTextInterface;
+class QAccessibleEvent;
+class QAccessibleInterface;
+class QAccessibleObject;
+class QAccessibleStateChangeEvent;
+class QAccessibleTableCellInterface;
+class QAccessibleTextCursorEvent;
+class QAccessibleTextInsertEvent;
+class QAccessibleTextInterface;
+class QAccessibleTextRemoveEvent;
+class QAccessibleTextSelectionEvent;
+class QAccessibleTextUpdateEvent;
+class QAccessibleValueChangeEvent;
+class QAccessibleValueInterface;
+class QActionEvent;
+class QBackingStore;
+class QBitmap;
+class QBrush;
+class QCloseEvent;
+class QColorTransform;
+class QConicalGradient;
+class QCursor;
+class QDesktopServices;
+class QDrag;
+class QDragEnterEvent;
+class QDragLeaveEvent;
+class QDragMoveEvent;
+class QDropEvent;
+class QEnterEvent;
+class QExposeEvent;
+class QFileOpenEvent;
+class QFocusEvent;
+class QFontInfo;
+class QFontMetrics;
+class QFontMetricsF;
+class QGuiApplication;
+class QHelpEvent;
+class QHideEvent;
+class QHoverEvent;
+class QIconDragEvent;
+class QInputEvent;
+class QInputMethodQueryEvent;
+class QIntValidator;
+class QKeyEvent;
+class QLinearGradient;
+class QMouseEvent;
+class QMoveEvent;
+class QNativeGestureEvent;
+class QOffscreenSurface;
+class QOpenGLContextGroup;
+class QOpenGLExtraFunctions;
+class QPaintDeviceWindow;
+class QPaintEngineState;
+class QPaintEvent;
+class QPainterPathStroker;
+class QPdfWriter;
+class QPen;
+class QPicture;
+class QPixmap;
+class QPointerEvent;
+class QPointingDeviceUniqueId;
+class QPolygon;
+class QPolygonF;
+class QPyTextObject;
+class QQuaternion;
+class QRadialGradient;
+class QRasterWindow;
+class QRegularExpressionValidator;
+class QResizeEvent;
+class QScreen;
+class QScrollPrepareEvent;
+class QShortcut;
+class QShortcutEvent;
+class QShowEvent;
+class QSinglePointEvent;
+class QStandardItemModel;
+class QStatusTipEvent;
+class QStyleHints;
+class QSyntaxHighlighter;
+class QTabletEvent;
+class QTextBlockGroup;
+class QTextBlockUserData;
+class QTextDocumentFragment;
+class QTextDocumentWriter;
+class QTextFragment;
+class QTextImageFormat;
+class QTextInlineObject;
+class QTextList;
+class QTextObject;
+class QTextObjectInterface;
+class QTextTable;
+class QTextTableCell;
+class QTextTableCellFormat;
+class QTextTableFormat;
+class QToolBarChangeEvent;
+class QTouchEvent;
+class QUndoCommand;
+class QUndoGroup;
+class QUndoStack;
+class QVector2D;
+class QVector3D;
+class QVector4D;
+class QWhatsThisClickedEvent;
+class QWheelEvent;
+class QWindowStateChangeEvent;
 
+namespace QtGuiHelper {
+    class QOverrideCursorGuard;
+}
 // Type indices
 enum : int {
     SBK_QABSTRACTFILEICONPROVIDER_ICONTYPE_IDX               = 1,
