@@ -16,40 +16,23 @@
 #include <pyside6_qtcore_python.h>
 
 // Bound library includes
-#include <QtHelp/qhelpfilterdata.h>
-#include <QtHelp/qhelpenginecore.h>
-#include <QtHelp/qhelplink.h>
 #include <QtHelp/qhelpsearchengine.h>
-#include <QtHelp/qhelpfilterengine.h>
-#include <QtHelp/qhelpfiltersettingswidget.h>
-#include <QtHelp/qhelpsearchquerywidget.h>
-#include <QtHelp/qcompressedhelpinfo.h>
-#include <QtHelp/qhelpengine.h>
-#include <QtHelp/qhelpsearchresultwidget.h>
-#include <QtHelp/qhelpcontentwidget.h>
-#include <QtHelp/qhelpindexwidget.h>
-// Conversion Includes - Primitive Types
-#include <QAnyStringView>
-#include <QString>
-#include <QStringList>
-#include <QStringView>
-
-// Conversion Includes - Container Types
-#include <pysideqflags.h>
-#include <QList>
-#include <QMap>
-#include <pysideqflags.h>
-#include <QMultiMap>
-#include <QPair>
-#include <QQueue>
-#include <QSet>
-#include <QStack>
-#include <list>
-#include <map>
-#include <utility>
-#include <unordered_map>
-#include <vector>
-
+class QCompressedHelpInfo;
+class QHelpContentItem;
+class QHelpContentModel;
+class QHelpContentWidget;
+class QHelpEngine;
+class QHelpEngineCore;
+class QHelpFilterData;
+class QHelpFilterEngine;
+class QHelpFilterSettingsWidget;
+class QHelpIndexModel;
+class QHelpIndexWidget;
+struct QHelpLink;
+class QHelpSearchEngine;
+class QHelpSearchQueryWidget;
+class QHelpSearchResult;
+class QHelpSearchResultWidget;
 // Type indices
 enum : int {
     SBK_QCOMPRESSEDHELPINFO_IDX                              = 0,
