@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2022 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt for Python.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2022 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 
 #ifndef SBK_QTMULTIMEDIA_PYTHON_H
@@ -52,51 +16,30 @@
 #include <pyside6_qtnetwork_python.h>
 
 // Bound library includes
-#include <QtMultimedia/qaudiodevice.h>
 #include <QtMultimedia/qcamera.h>
+#include <QtMultimedia/qvideoframe.h>
+#include <QtMultimedia/qmediaformat.h>
+#include <QtMultimedia/qaudiodecoder.h>
+#include <QtMultimedia/qmediarecorder.h>
+#include <QtMultimedia/qmediatimerange.h>
+#include <QtMultimedia/qaudiodevice.h>
 #include <QtMultimedia/qcameradevice.h>
 #include <QtMultimedia/qvideoframeformat.h>
-#include <QtMultimedia/qvideoframe.h>
-#include <QtMultimedia/qaudiosource.h>
-#include <QtMultimedia/qaudioinput.h>
-#include <QtMultimedia/qaudiooutput.h>
 #include <QtMultimedia/qmediaplayer.h>
-#include <QtMultimedia/qmediaformat.h>
 #include <QtMultimedia/qaudio.h>
-#include <QtMultimedia/qaudiobuffer.h>
-#include <QtMultimedia/qaudiodecoder.h>
-#include <QtMultimedia/qmediadevices.h>
-#include <QtMultimedia/qmediarecorder.h>
-#include <QtMultimedia/qmediacapturesession.h>
 #include <QtMultimedia/qsoundeffect.h>
 #include <QtMultimedia/qimagecapture.h>
 #include <QtMultimedia/qmediametadata.h>
 #include <QtMultimedia/qaudioformat.h>
-#include <QtMultimedia/qmediatimerange.h>
-#include <QtMultimedia/qaudiosink.h>
-#include <QtMultimedia/qvideosink.h>
-// Conversion Includes - Primitive Types
-#include <QAnyStringView>
-#include <QString>
-#include <QStringList>
-#include <QStringView>
-
-// Conversion Includes - Container Types
-#include <pysideqflags.h>
-#include <QList>
-#include <QMap>
-#include <pysideqflags.h>
-#include <QMultiMap>
-#include <QPair>
-#include <QQueue>
-#include <QSet>
-#include <QStack>
-#include <list>
-#include <map>
-#include <utility>
-#include <unordered_map>
-#include <vector>
-
+class QAudioBuffer;
+class QAudioInput;
+class QAudioOutput;
+class QAudioSink;
+class QAudioSource;
+class QCameraFormat;
+class QMediaCaptureSession;
+class QMediaDevices;
+class QVideoSink;
 // Type indices
 enum : int {
     SBK_QAUDIO_ERROR_IDX                                     = 1,
@@ -161,12 +104,15 @@ enum : int {
     SBK_QVIDEOFRAME_MAPMODE_IDX                              = 60,
     SBK_QVIDEOFRAME_ROTATIONANGLE_IDX                        = 61,
     SBK_QVIDEOFRAME_IDX                                      = 58,
-    SBK_QVIDEOFRAMEFORMAT_PIXELFORMAT_IDX                    = 64,
-    SBK_QVIDEOFRAMEFORMAT_DIRECTION_IDX                      = 63,
-    SBK_QVIDEOFRAMEFORMAT_YCBCRCOLORSPACE_IDX                = 65,
+    SBK_QVIDEOFRAMEFORMAT_PIXELFORMAT_IDX                    = 67,
+    SBK_QVIDEOFRAMEFORMAT_DIRECTION_IDX                      = 66,
+    SBK_QVIDEOFRAMEFORMAT_YCBCRCOLORSPACE_IDX                = 68,
+    SBK_QVIDEOFRAMEFORMAT_COLORSPACE_IDX                     = 64,
+    SBK_QVIDEOFRAMEFORMAT_COLORTRANSFER_IDX                  = 65,
+    SBK_QVIDEOFRAMEFORMAT_COLORRANGE_IDX                     = 63,
     SBK_QVIDEOFRAMEFORMAT_IDX                                = 62,
-    SBK_QVIDEOSINK_IDX                                       = 66,
-    SBK_QtMultimedia_IDX_COUNT                               = 67
+    SBK_QVIDEOSINK_IDX                                       = 69,
+    SBK_QtMultimedia_IDX_COUNT                               = 70
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtMultimediaTypes;
@@ -272,6 +218,9 @@ template<> inline PyTypeObject *SbkType< ::QVideoFrame >() { return reinterpret_
 template<> inline PyTypeObject *SbkType< ::QVideoFrameFormat::PixelFormat >() { return SbkPySide6_QtMultimediaTypes[SBK_QVIDEOFRAMEFORMAT_PIXELFORMAT_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QVideoFrameFormat::Direction >() { return SbkPySide6_QtMultimediaTypes[SBK_QVIDEOFRAMEFORMAT_DIRECTION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QVideoFrameFormat::YCbCrColorSpace >() { return SbkPySide6_QtMultimediaTypes[SBK_QVIDEOFRAMEFORMAT_YCBCRCOLORSPACE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QVideoFrameFormat::ColorSpace >() { return SbkPySide6_QtMultimediaTypes[SBK_QVIDEOFRAMEFORMAT_COLORSPACE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QVideoFrameFormat::ColorTransfer >() { return SbkPySide6_QtMultimediaTypes[SBK_QVIDEOFRAMEFORMAT_COLORTRANSFER_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QVideoFrameFormat::ColorRange >() { return SbkPySide6_QtMultimediaTypes[SBK_QVIDEOFRAMEFORMAT_COLORRANGE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QVideoFrameFormat >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtMultimediaTypes[SBK_QVIDEOFRAMEFORMAT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QVideoSink >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtMultimediaTypes[SBK_QVIDEOSINK_IDX]); }
 QT_WARNING_POP
