@@ -19,62 +19,51 @@
 #include <QtNetwork/qlocalserver.h>
 #include <QtNetwork/qnetworkaccessmanager.h>
 #include <QtNetwork/qnetworkinterface.h>
-#include <QtNetwork/qabstractnetworkcache.h>
-#include <QtNetwork/qauthenticator.h>
-#include <QtNetwork/qnetworkdatagram.h>
-#include <QtNetwork/qudpsocket.h>
-#include <QtNetwork/qnetworkcookiejar.h>
-#include <QtNetwork/qnetworkdiskcache.h>
 #include <QtNetwork/qnetworkproxy.h>
 #include <QtNetwork/qlocalsocket.h>
-#include <QtNetwork/qsslcipher.h>
 #include <QtNetwork/qocspresponse.h>
-#include <QtNetwork/qsslcertificateextension.h>
-#include <QtNetwork/qtcpsocket.h>
 #include <QtNetwork/qsslerror.h>
 #include <QtNetwork/qssldiffiehellmanparameters.h>
 #include <QtNetwork/qhstspolicy.h>
 #include <QtNetwork/qhttpmultipart.h>
 #include <QtNetwork/qdnslookup.h>
 #include <QtNetwork/qnetworkreply.h>
-#include <QtNetwork/qtcpserver.h>
 #include <QtNetwork/qssl.h>
 #include <QtNetwork/qpassworddigestor.h>
-#include <QtNetwork/qsslserver.h>
 #include <QtNetwork/qabstractsocket.h>
 #include <QtNetwork/qhostaddress.h>
 #include <QtNetwork/qhostinfo.h>
-#include <QtNetwork/qhttp2configuration.h>
-#include <QtNetwork/qsslellipticcurve.h>
 #include <QtNetwork/qsslcertificate.h>
-#include <QtNetwork/qsslkey.h>
 #include <QtNetwork/qsslconfiguration.h>
 #include <QtNetwork/qnetworkcookie.h>
 #include <QtNetwork/qdtls.h>
-#include <QtNetwork/qsslpresharedkeyauthenticator.h>
 #include <QtNetwork/qnetworkrequest.h>
-// Conversion Includes - Primitive Types
-#include <QAnyStringView>
-#include <QString>
-#include <QStringList>
-#include <QStringView>
-
-// Conversion Includes - Container Types
-#include <pysideqflags.h>
-#include <QList>
-#include <QMap>
-#include <pysideqflags.h>
-#include <QMultiMap>
-#include <QPair>
-#include <QQueue>
-#include <QSet>
-#include <QStack>
-#include <list>
-#include <map>
-#include <utility>
-#include <unordered_map>
-#include <vector>
-
+class QAbstractNetworkCache;
+class QAuthenticator;
+class QDnsDomainNameRecord;
+class QDnsHostAddressRecord;
+class QDnsMailExchangeRecord;
+class QDnsServiceRecord;
+class QDnsTextRecord;
+class QDtlsClientVerifier;
+class QHttp2Configuration;
+class QHttpPart;
+class QIPv6Address;
+class QNetworkCacheMetaData;
+class QNetworkCookieJar;
+class QNetworkDatagram;
+class QNetworkDiskCache;
+class QNetworkProxyFactory;
+class QOcspResponse;
+class QSslCertificateExtension;
+class QSslCipher;
+class QSslEllipticCurve;
+class QSslKey;
+class QSslPreSharedKeyAuthenticator;
+class QSslServer;
+class QTcpServer;
+class QTcpSocket;
+class QUdpSocket;
 // Type indices
 enum : int {
     SBK_QABSTRACTNETWORKCACHE_IDX                            = 0,
