@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2022 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt for Python.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2022 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 
 #ifndef SBK_QTOPENGL_PYTHON_H
@@ -51,68 +15,49 @@
 #include <pyside6_qtgui_python.h>
 
 // Bound library includes
-#include <QtOpenGL/qopenglfunctions_1_0.h>
 #include <QtOpenGL/qopenglbuffer.h>
-#include <QtOpenGL/qopenglfunctions_4_0_core.h>
-#include <QtOpenGL/qopengltimerquery.h>
-#include <QtOpenGL/qopenglversionfunctions.h>
-#include <QtOpenGL/qopenglfunctions_4_1_core.h>
-#include <QtOpenGL/qopenglfunctions_4_3_compatibility.h>
-#include <QtOpenGL/qopenglfunctions_3_2_core.h>
-#include <QtOpenGL/qopenglfunctions_4_3_core.h>
-#include <QtOpenGL/qopenglfunctions_3_1.h>
-#include <QtOpenGL/qopenglfunctions_3_0.h>
-#include <QtOpenGL/qopenglversionfunctionsfactory.h>
 #include <QtOpenGL/qopengldebug.h>
-#include <QtOpenGL/qopenglfunctions_4_0_compatibility.h>
 #include <QtOpenGL/qopengltexture.h>
-#include <QtOpenGL/qopenglfunctions_4_1_compatibility.h>
-#include <QtOpenGL/qopenglfunctions_2_1.h>
-#include <QtOpenGL/qopenglfunctions_4_2_compatibility.h>
-#include <QtOpenGL/qopenglfunctions_1_1.h>
-#include <QtOpenGL/qopenglfunctions_3_3_compatibility.h>
-#include <QtOpenGL/qopenglpaintdevice.h>
-#include <QtOpenGL/qopenglversionprofile.h>
-#include <QtOpenGL/qopenglfunctions_1_3.h>
 #include <QtOpenGL/qopenglvertexarrayobject.h>
-#include <QtOpenGL/qopenglfunctions_1_2.h>
-#include <QtOpenGL/qopenglfunctions_3_3_core.h>
-#include <QtOpenGL/qopenglfunctions_4_5_core.h>
-#include <QtOpenGL/qopenglfunctions_4_5_compatibility.h>
-#include <QtOpenGL/qopenglfunctions_4_4_compatibility.h>
 #include <QtOpenGL/qopenglshaderprogram.h>
 #include <QtOpenGL/qopenglwindow.h>
-#include <QtOpenGL/qopenglfunctions_4_2_core.h>
-#include <QtOpenGL/qopenglpixeltransferoptions.h>
-#include <QtOpenGL/qopenglfunctions_1_5.h>
-#include <QtOpenGL/qopenglfunctions_2_0.h>
-#include <QtOpenGL/qopenglfunctions_3_2_compatibility.h>
 #include <QtOpenGL/qopengltextureblitter.h>
 #include <QtOpenGL/qopenglframebufferobject.h>
-#include <QtOpenGL/qopenglfunctions_1_4.h>
-#include <QtOpenGL/qopenglfunctions_4_4_core.h>
-// Conversion Includes - Primitive Types
-#include <QAnyStringView>
-#include <QString>
-#include <QStringList>
-#include <QStringView>
-
-// Conversion Includes - Container Types
-#include <pysideqflags.h>
-#include <QList>
-#include <QMap>
-#include <pysideqflags.h>
-#include <QMultiMap>
-#include <QPair>
-#include <QQueue>
-#include <QSet>
-#include <QStack>
-#include <list>
-#include <map>
-#include <utility>
-#include <unordered_map>
-#include <vector>
-
+class QAbstractOpenGLFunctions;
+class QOpenGLFramebufferObjectFormat;
+class QOpenGLFunctions_1_0;
+class QOpenGLFunctions_1_1;
+class QOpenGLFunctions_1_2;
+class QOpenGLFunctions_1_3;
+class QOpenGLFunctions_1_4;
+class QOpenGLFunctions_1_5;
+class QOpenGLFunctions_2_0;
+class QOpenGLFunctions_2_1;
+class QOpenGLFunctions_3_0;
+class QOpenGLFunctions_3_1;
+class QOpenGLFunctions_3_2_Compatibility;
+class QOpenGLFunctions_3_2_Core;
+class QOpenGLFunctions_3_3_Compatibility;
+class QOpenGLFunctions_3_3_Core;
+class QOpenGLFunctions_4_0_Compatibility;
+class QOpenGLFunctions_4_0_Core;
+class QOpenGLFunctions_4_1_Compatibility;
+class QOpenGLFunctions_4_1_Core;
+class QOpenGLFunctions_4_2_Compatibility;
+class QOpenGLFunctions_4_2_Core;
+class QOpenGLFunctions_4_3_Compatibility;
+class QOpenGLFunctions_4_3_Core;
+class QOpenGLFunctions_4_4_Compatibility;
+class QOpenGLFunctions_4_4_Core;
+class QOpenGLFunctions_4_5_Compatibility;
+class QOpenGLFunctions_4_5_Core;
+class QOpenGLPaintDevice;
+class QOpenGLPixelTransferOptions;
+class QOpenGLShaderProgram;
+class QOpenGLTimeMonitor;
+class QOpenGLTimerQuery;
+class QOpenGLVersionFunctionsFactory;
+class QOpenGLVersionProfile;
 // Type indices
 enum : int {
     SBK_QABSTRACTOPENGLFUNCTIONS_IDX                         = 0,
@@ -161,43 +106,43 @@ enum : int {
     SBK_QOPENGLFUNCTIONS_4_4_CORE_IDX                        = 45,
     SBK_QOPENGLFUNCTIONS_4_5_COMPATIBILITY_IDX               = 46,
     SBK_QOPENGLFUNCTIONS_4_5_CORE_IDX                        = 47,
-    SBK_QOPENGLPAINTDEVICE_IDX                               = 49,
-    SBK_QOPENGLPIXELTRANSFEROPTIONS_IDX                      = 50,
-    SBK_QOPENGLSHADER_SHADERTYPEBIT_IDX                      = 52,
+    SBK_QOPENGLPAINTDEVICE_IDX                               = 48,
+    SBK_QOPENGLPIXELTRANSFEROPTIONS_IDX                      = 49,
+    SBK_QOPENGLSHADER_SHADERTYPEBIT_IDX                      = 51,
     SBK_QFLAGS_QOPENGLSHADER_SHADERTYPEBIT_IDX               = 5,
-    SBK_QOPENGLSHADER_IDX                                    = 51,
-    SBK_QOPENGLSHADERPROGRAM_IDX                             = 53,
-    SBK_QOPENGLTEXTURE_TARGET_IDX                            = 68,
-    SBK_QOPENGLTEXTURE_BINDINGTARGET_IDX                     = 55,
-    SBK_QOPENGLTEXTURE_MIPMAPGENERATION_IDX                  = 63,
-    SBK_QOPENGLTEXTURE_TEXTUREUNITRESET_IDX                  = 71,
-    SBK_QOPENGLTEXTURE_TEXTUREFORMAT_IDX                     = 69,
-    SBK_QOPENGLTEXTURE_TEXTUREFORMATCLASS_IDX                = 70,
-    SBK_QOPENGLTEXTURE_CUBEMAPFACE_IDX                       = 59,
-    SBK_QOPENGLTEXTURE_PIXELFORMAT_IDX                       = 64,
-    SBK_QOPENGLTEXTURE_PIXELTYPE_IDX                         = 65,
-    SBK_QOPENGLTEXTURE_SWIZZLECOMPONENT_IDX                  = 66,
-    SBK_QOPENGLTEXTURE_SWIZZLEVALUE_IDX                      = 67,
-    SBK_QOPENGLTEXTURE_WRAPMODE_IDX                          = 72,
-    SBK_QOPENGLTEXTURE_COORDINATEDIRECTION_IDX               = 58,
-    SBK_QOPENGLTEXTURE_FEATURE_IDX                           = 61,
+    SBK_QOPENGLSHADER_IDX                                    = 50,
+    SBK_QOPENGLSHADERPROGRAM_IDX                             = 52,
+    SBK_QOPENGLTEXTURE_TARGET_IDX                            = 67,
+    SBK_QOPENGLTEXTURE_BINDINGTARGET_IDX                     = 54,
+    SBK_QOPENGLTEXTURE_MIPMAPGENERATION_IDX                  = 62,
+    SBK_QOPENGLTEXTURE_TEXTUREUNITRESET_IDX                  = 70,
+    SBK_QOPENGLTEXTURE_TEXTUREFORMAT_IDX                     = 68,
+    SBK_QOPENGLTEXTURE_TEXTUREFORMATCLASS_IDX                = 69,
+    SBK_QOPENGLTEXTURE_CUBEMAPFACE_IDX                       = 58,
+    SBK_QOPENGLTEXTURE_PIXELFORMAT_IDX                       = 63,
+    SBK_QOPENGLTEXTURE_PIXELTYPE_IDX                         = 64,
+    SBK_QOPENGLTEXTURE_SWIZZLECOMPONENT_IDX                  = 65,
+    SBK_QOPENGLTEXTURE_SWIZZLEVALUE_IDX                      = 66,
+    SBK_QOPENGLTEXTURE_WRAPMODE_IDX                          = 71,
+    SBK_QOPENGLTEXTURE_COORDINATEDIRECTION_IDX               = 57,
+    SBK_QOPENGLTEXTURE_FEATURE_IDX                           = 60,
     SBK_QFLAGS_QOPENGLTEXTURE_FEATURE_IDX                    = 6,
-    SBK_QOPENGLTEXTURE_DEPTHSTENCILMODE_IDX                  = 60,
-    SBK_QOPENGLTEXTURE_COMPARISONFUNCTION_IDX                = 56,
-    SBK_QOPENGLTEXTURE_COMPARISONMODE_IDX                    = 57,
-    SBK_QOPENGLTEXTURE_FILTER_IDX                            = 62,
-    SBK_QOPENGLTEXTURE_IDX                                   = 54,
-    SBK_QOPENGLTEXTUREBLITTER_ORIGIN_IDX                     = 74,
-    SBK_QOPENGLTEXTUREBLITTER_IDX                            = 73,
-    SBK_QOPENGLTIMEMONITOR_IDX                               = 75,
-    SBK_QOPENGLTIMERQUERY_IDX                                = 76,
-    SBK_QOPENGLVERSIONFUNCTIONSFACTORY_IDX                   = 77,
-    SBK_QOPENGLVERSIONPROFILE_IDX                            = 78,
-    SBK_QOPENGLVERTEXARRAYOBJECT_IDX                         = 79,
-    SBK_QOPENGLVERTEXARRAYOBJECT_BINDER_IDX                  = 80,
-    SBK_QOPENGLWINDOW_UPDATEBEHAVIOR_IDX                     = 82,
-    SBK_QOPENGLWINDOW_IDX                                    = 81,
-    SBK_QtOpenGL_IDX_COUNT                                   = 83
+    SBK_QOPENGLTEXTURE_DEPTHSTENCILMODE_IDX                  = 59,
+    SBK_QOPENGLTEXTURE_COMPARISONFUNCTION_IDX                = 55,
+    SBK_QOPENGLTEXTURE_COMPARISONMODE_IDX                    = 56,
+    SBK_QOPENGLTEXTURE_FILTER_IDX                            = 61,
+    SBK_QOPENGLTEXTURE_IDX                                   = 53,
+    SBK_QOPENGLTEXTUREBLITTER_ORIGIN_IDX                     = 73,
+    SBK_QOPENGLTEXTUREBLITTER_IDX                            = 72,
+    SBK_QOPENGLTIMEMONITOR_IDX                               = 74,
+    SBK_QOPENGLTIMERQUERY_IDX                                = 75,
+    SBK_QOPENGLVERSIONFUNCTIONSFACTORY_IDX                   = 76,
+    SBK_QOPENGLVERSIONPROFILE_IDX                            = 77,
+    SBK_QOPENGLVERTEXARRAYOBJECT_IDX                         = 78,
+    SBK_QOPENGLVERTEXARRAYOBJECT_BINDER_IDX                  = 79,
+    SBK_QOPENGLWINDOW_UPDATEBEHAVIOR_IDX                     = 81,
+    SBK_QOPENGLWINDOW_IDX                                    = 80,
+    SBK_QtOpenGL_IDX_COUNT                                   = 82
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtOpenGLTypes;
