@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2022 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt for Python.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2022 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 
 #ifndef SBK_QTQML_PYTHON_H
@@ -51,56 +15,37 @@
 #include <pyside6_qtnetwork_python.h>
 
 // Bound library includes
-#include <QtQml/qjsvalueiterator.h>
-#include <QtQml/qqmlcomponent.h>
-#include <QtQml/qqmlextensionplugin.h>
-#include <QtQml/qqmlpropertymap.h>
-#include <QtQml/qjsvalue.h>
-#include <QtQml/qjsprimitivevalue.h>
-#include <QtQml/qqmlnetworkaccessmanagerfactory.h>
-#include <QtQml/qqmlapplicationengine.h>
-#include <QtQml/qqmlcontext.h>
-#include <QtQml/qqmlfile.h>
-#include <QtQml/qqmlexpression.h>
-#include <QtQml/qqmlfileselector.h>
-#include <qpyqmlpropertyvaluesource.h>
 #include <QtQml/qjsmanagedvalue.h>
 #include <QtQml/qqmldebug.h>
-#include <QtQml/qqmlextensioninterface.h>
 #include <QtQml/qqml.h>
+#include <QtQml/qqmlcomponent.h>
+#include <QtQml/qjsvalue.h>
+#include <QtQml/qjsprimitivevalue.h>
+#include <QtQml/qqmlcontext.h>
+#include <QtQml/qqmlfile.h>
 #include <QtQml/qqmlincubator.h>
-#include <QtQml/qqmlpropertyvaluesource.h>
-#include <qpyqmlparserstatus.h>
 #include <QtQml/qqmlabstracturlinterceptor.h>
-#include <QtQml/qqmlparserstatus.h>
 #include <QtQml/qjsengine.h>
 #include <QtQml/qqmlengine.h>
-#include <QtQml/qqmllist.h>
-#include <QtQml/qqmlerror.h>
-#include <QtQml/qqmlscriptstring.h>
 #include <QtQml/qqmlproperty.h>
-// Conversion Includes - Primitive Types
-#include <QAnyStringView>
-#include <QString>
-#include <QStringList>
-#include <QStringView>
-
-// Conversion Includes - Container Types
-#include <pysideqflags.h>
-#include <QList>
-#include <QMap>
-#include <pysideqflags.h>
-#include <QMultiMap>
-#include <QPair>
-#include <QQueue>
-#include <QSet>
-#include <QStack>
-#include <list>
-#include <map>
-#include <utility>
-#include <unordered_map>
-#include <vector>
-
+class QJSValueIterator;
+class QPyQmlParserStatus;
+class QPyQmlPropertyValueSource;
+class QQmlApplicationEngine;
+class QQmlEngine;
+class QQmlError;
+class QQmlExpression;
+class QQmlExtensionInterface;
+class QQmlExtensionPlugin;
+class QQmlFileSelector;
+class QQmlIncubationController;
+class QQmlListReference;
+class QQmlNetworkAccessManagerFactory;
+class QQmlParserStatus;
+class QQmlPropertyMap;
+class QQmlPropertyValueSource;
+class QQmlScriptString;
+class QQmlTypesExtensionInterface;
 // Begin code injection
 // Volatile Bool Ptr type definition for QQmlIncubationController::incubateWhile(std::atomic<bool> *, int)
 #include <atomic>
