@@ -18,56 +18,45 @@
 #include <pyside6_qtqml_python.h>
 
 // Bound library includes
-#include <QtQuick/qquickrendercontrol.h>
-#include <QtQuick/qsgflatcolormaterial.h>
-#include <QtQuick/qquickgraphicsconfiguration.h>
-#include <QtQuick/qsgtexturematerial.h>
-#include <QtQuick/qquickrendertarget.h>
 #include <QtQuick/qquickpainteditem.h>
-#include <QtQuick/qquicktextdocument.h>
 #include <QtQuick/qquickview.h>
 #include <QtQuick/qsgrendererinterface.h>
-#include <QtQuick/qsgvertexcolormaterial.h>
 #include <QtQuick/qsgmaterial.h>
 #include <QtQuick/qsgsimpletexturenode.h>
-#include <QtQuick/qquickitemgrabresult.h>
-#include <QtQuick/qsgtextureprovider.h>
 #include <QtQuick/qsgtexture.h>
 #include <QtQuick/qquickitem.h>
 #include <QtQuick/qsgmaterialshader.h>
 #include <QtQuick/qsgnode.h>
 #include <QtQuick/qquickframebufferobject.h>
-#include <QtQuick/qquickgraphicsdevice.h>
 #include <QtQuick/qsgrendernode.h>
 #include <QtQuick/qsggeometry.h>
 #include <qsharedpointer.h>
-#include <QtQuick/qsgrectanglenode.h>
-#include <QtQuick/qsgsimplerectnode.h>
-#include <QtQuick/qsgmaterialtype.h>
-#include <QtQuick/qquickimageprovider.h>
 #include <QtQuick/qquickwindow.h>
-// Conversion Includes - Primitive Types
-#include <QAnyStringView>
-#include <QString>
-#include <QStringList>
-#include <QStringView>
-
-// Conversion Includes - Container Types
-#include <pysideqflags.h>
-#include <QList>
-#include <QMap>
-#include <pysideqflags.h>
-#include <QMultiMap>
-#include <QPair>
-#include <QQueue>
-#include <QSet>
-#include <QStack>
-#include <list>
-#include <map>
-#include <utility>
-#include <unordered_map>
-#include <vector>
-
+class QQuickAsyncImageProvider;
+class QQuickGraphicsConfiguration;
+class QQuickGraphicsDevice;
+class QQuickImageProvider;
+class QQuickImageResponse;
+class QQuickItemGrabResult;
+class QQuickRenderControl;
+class QQuickRenderTarget;
+class QQuickTextDocument;
+class QQuickTextureFactory;
+class QQuickTransform;
+class QSGBasicGeometryNode;
+class QSGClipNode;
+class QSGDynamicTexture;
+class QSGFlatColorMaterial;
+class QSGGeometryNode;
+struct QSGMaterialType;
+class QSGOpacityNode;
+class QSGOpaqueTextureMaterial;
+class QSGRectangleNode;
+class QSGSimpleRectNode;
+class QSGTextureMaterial;
+class QSGTextureProvider;
+class QSGTransformNode;
+class QSGVertexColorMaterial;
 // Type indices
 enum : int {
     SBK_QQUICKASYNCIMAGEPROVIDER_IDX                         = 13,
