@@ -19,33 +19,11 @@
 #include <pyside6_qtqml_python.h>
 
 // Bound library includes
-#include <QtQuick3D/qquick3d.h>
 #include <QtQuick3D/qquick3dinstancing.h>
 #include <QtQuick3D/qquick3dtexturedata.h>
 #include <QtQuick3D/qquick3dgeometry.h>
 #include <QtQuick3D/qquick3dobject.h>
-// Conversion Includes - Primitive Types
-#include <QAnyStringView>
-#include <QString>
-#include <QStringList>
-#include <QStringView>
-
-// Conversion Includes - Container Types
-#include <pysideqflags.h>
-#include <QList>
-#include <QMap>
-#include <pysideqflags.h>
-#include <QMultiMap>
-#include <QPair>
-#include <QQueue>
-#include <QSet>
-#include <QStack>
-#include <list>
-#include <map>
-#include <utility>
-#include <unordered_map>
-#include <vector>
-
+class QQuick3D;
 // Type indices
 enum : int {
     SBK_QQUICK3D_IDX                                         = 0,
