@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2022 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt for Python.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2022 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 
 #ifndef SBK_QTSCXML_PYTHON_H
@@ -50,38 +14,27 @@
 #include <pyside6_qtcore_python.h>
 
 // Bound library includes
-#include <QtScxml/qscxmlstatemachine.h>
-#include <QtScxml/qscxmlinvokableservice.h>
-#include <QtScxml/qscxmltabledata.h>
-#include <QtScxml/qscxmlcompiler.h>
-#include <QtScxml/qscxmlexecutablecontent.h>
-#include <QtScxml/qscxmlcppdatamodel.h>
-#include <QtScxml/qscxmlnulldatamodel.h>
-#include <QtScxml/qscxmlerror.h>
 #include <QtScxml/qscxmldatamodel.h>
 #include <QtScxml/qscxmlevent.h>
-// Conversion Includes - Primitive Types
-#include <QAnyStringView>
-#include <QString>
-#include <QStringList>
-#include <QStringView>
-
-// Conversion Includes - Container Types
-#include <pysideqflags.h>
-#include <QList>
-#include <QMap>
-#include <pysideqflags.h>
-#include <QMultiMap>
-#include <QPair>
-#include <QQueue>
-#include <QSet>
-#include <QStack>
-#include <list>
-#include <map>
-#include <utility>
-#include <unordered_map>
-#include <vector>
+#include <QtScxml/qscxmlcompiler.h>
+#include <QtScxml/qscxmlexecutablecontent.h>
+class QScxmlCppDataModel;
+class QScxmlDynamicScxmlServiceFactory;
+class QScxmlError;
+class QScxmlInvokableService;
+class QScxmlInvokableServiceFactory;
+class QScxmlNullDataModel;
+class QScxmlStateMachine;
+class QScxmlStaticScxmlServiceFactory;
+class QScxmlTableData;
 
+namespace QScxmlExecutableContent {
+    struct AssignmentInfo;
+    struct EvaluatorInfo;
+    struct ForeachInfo;
+    struct InvokeInfo;
+    struct ParameterInfo;
+}
 // Type indices
 enum : int {
     SBK_QSCXMLCOMPILER_IDX                                   = 0,
