@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2022 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt for Python.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2022 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 
 #ifndef SBK_QTSENSORS_PYTHON_H
@@ -50,48 +14,63 @@
 #include <pyside6_qtcore_python.h>
 
 // Bound library includes
-#include <QtSensors/qambientlightsensor.h>
 #include <QtSensors/qaccelerometer.h>
-#include <QtSensors/qambienttemperaturesensor.h>
-#include <QtSensors/qrotationsensor.h>
+#include <QtSensors/qambientlightsensor.h>
 #include <QtSensors/qtapsensor.h>
-#include <QtSensors/qirproximitysensor.h>
-#include <QtSensors/qgyroscope.h>
-#include <QtSensors/qlidsensor.h>
-#include <QtSensors/qproximitysensor.h>
-#include <QtSensors/qhumiditysensor.h>
-#include <QtSensors/qtiltsensor.h>
-#include <QtSensors/qsensorplugin.h>
-#include <QtSensors/qpressuresensor.h>
-#include <QtSensors/qsensormanager.h>
-#include <QtSensors/qcompass.h>
-#include <QtSensors/qmagnetometer.h>
 #include <QtSensors/qsensor.h>
-#include <QtSensors/qlightsensor.h>
-#include <QtSensors/qsensorbackend.h>
 #include <QtSensors/qorientationsensor.h>
-// Conversion Includes - Primitive Types
-#include <QAnyStringView>
-#include <QString>
-#include <QStringList>
-#include <QStringView>
-
-// Conversion Includes - Container Types
-#include <pysideqflags.h>
-#include <QList>
-#include <QMap>
-#include <pysideqflags.h>
-#include <QMultiMap>
-#include <QPair>
-#include <QQueue>
-#include <QSet>
-#include <QStack>
-#include <list>
-#include <map>
-#include <utility>
-#include <unordered_map>
-#include <vector>
-
+class QAccelerometerFilter;
+class QAccelerometerReading;
+class QAmbientLightFilter;
+class QAmbientLightSensor;
+class QAmbientTemperatureFilter;
+class QAmbientTemperatureReading;
+class QAmbientTemperatureSensor;
+class QCompass;
+class QCompassFilter;
+class QCompassReading;
+class QGyroscope;
+class QGyroscopeFilter;
+class QGyroscopeReading;
+class QHumidityFilter;
+class QHumidityReading;
+class QHumiditySensor;
+class QIRProximityFilter;
+class QIRProximityReading;
+class QIRProximitySensor;
+class QLidFilter;
+class QLidReading;
+class QLidSensor;
+class QLightFilter;
+class QLightReading;
+class QLightSensor;
+class QMagnetometer;
+class QMagnetometerFilter;
+class QMagnetometerReading;
+class QOrientationFilter;
+class QOrientationSensor;
+class QPressureFilter;
+class QPressureReading;
+class QPressureSensor;
+class QProximityFilter;
+class QProximityReading;
+class QProximitySensor;
+class QRotationFilter;
+class QRotationReading;
+class QRotationSensor;
+class QSensorBackend;
+class QSensorBackendFactory;
+class QSensorChangesInterface;
+class QSensorFilter;
+class QSensorManager;
+class QSensorPluginInterface;
+class QSensorReading;
+class QTapFilter;
+class QTapSensor;
+class QTiltFilter;
+class QTiltReading;
+class QTiltSensor;
+struct qoutputrange;
 // Type indices
 enum : int {
     SBK_QACCELEROMETER_ACCELERATIONMODE_IDX                  = 1,
