@@ -17,36 +17,14 @@
 // Bound library includes
 #include <QtStateMachine/qabstracttransition.h>
 #include <QtStateMachine/qhistorystate.h>
-#include <QtStateMachine/qabstractstate.h>
-#include <QtStateMachine/qmouseeventtransition.h>
-#include <QtStateMachine/qeventtransition.h>
-#include <QtStateMachine/qfinalstate.h>
-#include <QtStateMachine/qkeyeventtransition.h>
 #include <QtStateMachine/qstate.h>
 #include <QtStateMachine/qstatemachine.h>
-#include <QtStateMachine/qsignaltransition.h>
-// Conversion Includes - Primitive Types
-#include <QAnyStringView>
-#include <QString>
-#include <QStringList>
-#include <QStringView>
-
-// Conversion Includes - Container Types
-#include <pysideqflags.h>
-#include <QList>
-#include <QMap>
-#include <pysideqflags.h>
-#include <QMultiMap>
-#include <QPair>
-#include <QQueue>
-#include <QSet>
-#include <QStack>
-#include <list>
-#include <map>
-#include <utility>
-#include <unordered_map>
-#include <vector>
-
+class QAbstractState;
+class QEventTransition;
+class QFinalState;
+class QKeyEventTransition;
+class QMouseEventTransition;
+class QSignalTransition;
 // Type indices
 enum : int {
     SBK_QABSTRACTSTATE_IDX                                   = 0,
