@@ -16,29 +16,7 @@
 #include <pyside6_qtcore_python.h>
 
 // Bound library includes
-#include <QtUiTools/quiloader.h>
-// Conversion Includes - Primitive Types
-#include <QAnyStringView>
-#include <QString>
-#include <QStringList>
-#include <QStringView>
-
-// Conversion Includes - Container Types
-#include <pysideqflags.h>
-#include <QList>
-#include <QMap>
-#include <pysideqflags.h>
-#include <QMultiMap>
-#include <QPair>
-#include <QQueue>
-#include <QSet>
-#include <QStack>
-#include <list>
-#include <map>
-#include <utility>
-#include <unordered_map>
-#include <vector>
-
+class QUiLoader;
 // Type indices
 enum : int {
     SBK_QUILOADER_IDX                                        = 0,
