@@ -15,28 +15,21 @@
 
 // Bound library includes
 #include <QtXml/qdom.h>
-// Conversion Includes - Primitive Types
-#include <QAnyStringView>
-#include <QString>
-#include <QStringList>
-#include <QStringView>
-
-// Conversion Includes - Container Types
-#include <pysideqflags.h>
-#include <QList>
-#include <QMap>
-#include <pysideqflags.h>
-#include <QMultiMap>
-#include <QPair>
-#include <QQueue>
-#include <QSet>
-#include <QStack>
-#include <list>
-#include <map>
-#include <utility>
-#include <unordered_map>
-#include <vector>
-
+class QDomAttr;
+class QDomCDATASection;
+class QDomCharacterData;
+class QDomComment;
+class QDomDocument;
+class QDomDocumentFragment;
+class QDomDocumentType;
+class QDomElement;
+class QDomEntity;
+class QDomEntityReference;
+class QDomNamedNodeMap;
+class QDomNodeList;
+class QDomNotation;
+class QDomProcessingInstruction;
+class QDomText;
 // Type indices
 enum : int {
     SBK_QDOMATTR_IDX                                         = 0,
