@@ -1,46 +1,243 @@
-/****************************************************************************
-**
-** Copyright (C) 2018 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt for Python.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2018 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 /*********************************************************************
  * INJECT CODE
  ********************************************************************/
 
+// @snippet gui-declarations
+void qt_set_sequence_auto_mnemonic(bool);
+// @snippet gui-declarations
+
+// @snippet qaccessible-pysidefactory
+// Helper for QAccessible::installFactory() that forwards the calls to
+// Python callables.
+class PySideAccessibleFactory
+{
+    PySideAccessibleFactory() = default;
+public:
+    ~PySideAccessibleFactory();
+
+    static PySideAccessibleFactory *instance() { return m_instance; }
+    static PySideAccessibleFactory *ensureInstance();
+
+    static void installFactory(PyObject *f);
+    static void cleanup();
+
+    static QAccessibleInterface *factory(const QString &key, QObject *o);
+
+private:
+    QAccessibleInterface *callFactories(const QString &key, QObject *o);
+
+    static PySideAccessibleFactory *m_instance;
+
+    QList<PyObject *> m_factoryFunctions;
+    QList<PyObject *> m_objects;
+};
+
+PySideAccessibleFactory *PySideAccessibleFactory::m_instance = nullptr;
+
+PySideAccessibleFactory::~PySideAccessibleFactory()
+{
+    QAccessible::removeFactory(PySideAccessibleFactory::factory);
+    if (!m_factoryFunctions.isEmpty()) {
+        Shiboken::GilState state;
+        for (auto *f : m_factoryFunctions)
+            Py_DECREF(f);
+        for (auto *o : m_objects)
+            Py_DECREF(o);
+    }
+}
+
+PySideAccessibleFactory *PySideAccessibleFactory::ensureInstance()
+{
+    if (m_instance == nullptr) {
+        m_instance = new PySideAccessibleFactory;
+        QAccessible::installFactory(PySideAccessibleFactory::factory);
+        qAddPostRoutine(PySideAccessibleFactory::cleanup);
+    }
+    return m_instance;
+}
+
+void PySideAccessibleFactory::installFactory(PyObject *f)
+{
+    if (m_instance != nullptr) {
+        Py_INCREF(f);
+        m_instance->m_factoryFunctions.append(f);
+    }
+}
+
+void PySideAccessibleFactory::cleanup()
+{
+    delete m_instance;
+    m_instance = nullptr;
+}
+
+QAccessibleInterface *PySideAccessibleFactory::factory(const QString &key, QObject *o)
+{
+    return m_instance ? m_instance->callFactories(key, o) : nullptr;
+}
+
+QAccessibleInterface *PySideAccessibleFactory::callFactories(const QString &key, QObject *o)
+{
+    Shiboken::GilState state;
+    Shiboken::AutoDecRef arglist(PyTuple_New(2));
+    PyTuple_SET_ITEM(arglist, 0, %CONVERTTOPYTHON[QString](key));
+    PyTuple_SET_ITEM(arglist, 1, %CONVERTTOPYTHON[QObject *](o));
+
+    for (auto *f : m_factoryFunctions) {
+        if (PyObject *pyResult = PyObject_CallObject(f, arglist)) {
+            if (pyResult != Py_None) {
+                m_objects.append(pyResult);
+                QAccessibleInterface* result = %CONVERTTOCPP[QAccessibleInterface *](pyResult);
+                return result;
+            }
+            Py_DECREF(pyResult);
+        }
+    }
+
+    return nullptr;
+}
+// @snippet qaccessible-pysidefactory
+
+// @snippet qaccessible-installfactory
+PySideAccessibleFactory::ensureInstance()->installFactory(%1);
+// @snippet qaccessible-installfactory
+
+// @snippet qaction-menu
+// %CPPSELF->menu(); // pretend it was called.
+QObject *object = %CPPSELF->menu<QObject *>();
+%PYARG_0 = %CONVERTTOPYTHON[QObject*](object);
+// @snippet qaction-menu
+
+// @snippet qopenglfunctions-glgetv-return-size
+// Return the number of return values of the glGetBoolean/Double/Integerv functions
+// cf https://registry.khronos.org/OpenGL-Refpages/gl4/html/glGet.xhtml
+static int glGetVReturnSize(GLenum pname)
+{
+    switch (pname) {
+    case GL_ALIASED_LINE_WIDTH_RANGE:
+    case GL_DEPTH_RANGE:
+    case GL_MAX_VIEWPORT_DIMS:
+#if !QT_CONFIG(opengles2)
+    case GL_POINT_SIZE_RANGE:
+    case GL_SMOOTH_LINE_WIDTH_RANGE:
+    case GL_VIEWPORT_BOUNDS_RANGE:
+#endif
+        return 2;
+    case GL_BLEND_COLOR:
+    case GL_COLOR_CLEAR_VALUE:
+    case GL_COLOR_WRITEMASK:
+    case GL_SCISSOR_BOX:
+    case GL_VIEWPORT:
+        return 4;
+    case GL_COMPRESSED_TEXTURE_FORMATS:
+        return GL_NUM_COMPRESSED_TEXTURE_FORMATS;
+    default:
+        break;
+    }
+    return 1;
+}
+// @snippet qopenglfunctions-glgetv-return-size
+
+// @snippet qopenglextrafunctions-glgeti-v-return-size
+// Return the number of return values of the indexed
+// glGetBoolean/Double/Integeri_v functions
+// cf https://registry.khronos.org/OpenGL-Refpages/gl4/html/glGet.xhtml
+static int glGetI_VReturnSize(GLenum pname)
+{
+    return pname == GL_VIEWPORT ? 4 : 1;
+}
+// @snippet qopenglextrafunctions-glgeti-v-return-size
+
+// @snippet qopenglfunctions-glgetbooleanv
+const int size = glGetVReturnSize(%1);
+QVarLengthArray<GLboolean> result(size, GL_FALSE);
+%CPPSELF.%FUNCTION_NAME(%ARGUMENT_NAMES, result.data());
+if (size == 1) {
+    %PYARG_0 = %CONVERTTOPYTHON[bool](result[0]);
+} else {
+    %PYARG_0 = Shiboken::Numpy::createByteArray1(size, result.constData());
+}
+// @snippet qopenglfunctions-glgetbooleanv
+
+// @snippet qopenglfunctions-glgetdoublev
+const int size = glGetVReturnSize(%1);
+QVarLengthArray<GLdouble> result(size, 0);
+%CPPSELF.%FUNCTION_NAME(%ARGUMENT_NAMES, result.data());
+if (size == 1) {
+    %PYARG_0 = %CONVERTTOPYTHON[double](result[0]);
+} else {
+    %PYARG_0 = Shiboken::Numpy::createDoubleArray1(size, result.constData());
+}
+// @snippet qopenglfunctions-glgetdoublev
+
+// @snippet qopenglfunctions-glgetfloatv
+const int size = glGetVReturnSize(%1);
+QVarLengthArray<GLfloat> result(size, 0);
+%CPPSELF.%FUNCTION_NAME(%ARGUMENT_NAMES, result.data());
+if (size == 1) {
+    %PYARG_0 = %CONVERTTOPYTHON[float](result[0]);
+} else {
+    %PYARG_0 = Shiboken::Numpy::createFloatArray1(size, result.constData());
+}
+// @snippet qopenglfunctions-glgetfloatv
+
+// @snippet qopenglfunctions-glgetintegerv
+const int size = glGetVReturnSize(%1);
+QVarLengthArray<GLint> result(size, 0);
+%CPPSELF.%FUNCTION_NAME(%ARGUMENT_NAMES, result.data());
+if (size == 1) {
+    %PYARG_0 = %CONVERTTOPYTHON[int](result[0]);
+} else {
+    %PYARG_0 = Shiboken::Numpy::createIntArray1(size, result.constData());
+}
+// @snippet qopenglfunctions-glgetintegerv
+
+// @snippet qopenglextrafunctions-glgetbooleani-v
+const int size = glGetI_VReturnSize(%1);
+QVarLengthArray<GLboolean> result(size, GL_FALSE);
+%CPPSELF.%FUNCTION_NAME(%ARGUMENT_NAMES, result.data());
+if (size == 1) {
+    %PYARG_0 = %CONVERTTOPYTHON[bool](result[0]);
+} else {
+    %PYARG_0 = Shiboken::Numpy::createByteArray1(size, result.constData());
+}
+// @snippet qopenglextrafunctions-glgetbooleani-v
+
+// @snippet qopenglextrafunctions-glgetdoublei-v
+const int size = glGetI_VReturnSize(%1);
+QVarLengthArray<GLdouble> result(size, 0);
+%CPPSELF.%FUNCTION_NAME(%ARGUMENT_NAMES, result.data());
+if (size == 1) {
+    %PYARG_0 = %CONVERTTOPYTHON[double](result[0]);
+} else {
+    %PYARG_0 = Shiboken::Numpy::createDoubleArray1(size, result.constData());
+}
+// @snippet qopenglextrafunctions-glgetdoublei-v
+
+// @snippet qopenglextrafunctions-glgetfloati-v
+const int size = glGetI_VReturnSize(%1);
+QVarLengthArray<GLfloat> result(size, 0);
+%CPPSELF.%FUNCTION_NAME(%ARGUMENT_NAMES, result.data());
+if (size == 1) {
+    %PYARG_0 = %CONVERTTOPYTHON[float](result[0]);
+} else {
+    %PYARG_0 = Shiboken::Numpy::createFloatArray1(size, result.constData());
+}
+// @snippet qopenglextrafunctions-glgetfloati-v
+
+// @snippet qopenglextrafunctions-glgetintegeri-v
+const int size = glGetI_VReturnSize(%1);
+QVarLengthArray<GLint> result(size, 0);
+%CPPSELF.%FUNCTION_NAME(%ARGUMENT_NAMES, result.data());
+if (size == 1) {
+    %PYARG_0 = %CONVERTTOPYTHON[int](result[0]);
+} else {
+    %PYARG_0 = Shiboken::Numpy::createIntArray1(size, result.constData());
+}
+// @snippet qopenglextrafunctions-glgetintegeri-v
+
 // @snippet glgetshadersource
 GLsizei bufSize = 4096;
 GLsizei length = bufSize - 1;
@@ -115,10 +312,22 @@ if (_i < 0 || _i >= %CPPSELF.count()) {
     PyErr_SetString(PyExc_IndexError, "index out of bounds");
     return 0;
 }
-int item = (*%CPPSELF)[_i];
-return %CONVERTTOPYTHON[int](item);
+QKeyCombination item = (*%CPPSELF)[_i];
+if (usingNewEnum())
+    return %CONVERTTOPYTHON[QKeyCombination](item);
+auto combined = item.toCombined();
+return %CONVERTTOPYTHON[int](combined);
 // @snippet qkeysequence-getitem
 
+// @snippet qkeysequence-repr
+auto ObTuple_Type = reinterpret_cast<PyObject *>(&PyTuple_Type);
+auto ObSelf_Type = reinterpret_cast<PyObject *>(Py_TYPE(%PYSELF));
+Shiboken::AutoDecRef surrogate(PyObject_CallFunctionObjArgs(ObTuple_Type, %PYSELF, nullptr));
+Shiboken::AutoDecRef argstr(PyObject_Repr(surrogate));
+Shiboken::AutoDecRef name(PyObject_GetAttrString(ObSelf_Type, "__name__"));
+return PyUnicode_Concat(name, argstr);
+// @snippet qkeysequence-repr
+
 // @snippet qpicture-data
 %PYARG_0 = Shiboken::Buffer::newObject(%CPPSELF.data(), %CPPSELF.size());
 // @snippet qpicture-data
@@ -140,7 +349,7 @@ if (doc) {
 // @snippet qtextblock-userdata
 
 // @snippet qpolygon-reduce
-const Py_ssize_t count = %CPPSELF.count();
+const Py_ssize_t count = %CPPSELF.size();
 PyObject *points = PyList_New(count);
 for (Py_ssize_t i = 0; i < count; ++i){
     int x, y;
@@ -160,10 +369,18 @@ for (Py_ssize_t i = 0; i < count; ++i){
 %0 = new %TYPE(QPixmap::fromImage(%1));
 // @snippet qpixmap
 
+// @snippet qicon-addpixmap
+const auto path = PySide::pyPathToQString(%PYARG_1);
+%CPPSELF->addPixmap(path);
+// @snippet qicon-addpixmap
+
 // @snippet qimage-decref-image-data
 static void imageDecrefDataHandler(void *data)
 {
+    // Avoid "Python memory allocator called without holding the GIL"
+    auto state = PyGILState_Ensure();
     Py_DECREF(reinterpret_cast<PyObject *>(data));
+    PyGILState_Release(state);
 }
 // @snippet qimage-decref-image-data
 
@@ -471,9 +688,18 @@ const auto points = PySide::Numpy::xyDataToQPointFList(%PYARG_1, %PYARG_2);
 // @snippet qpainter-drawpointsnp-numpy-x-y
 
 // @snippet qpainter-drawpolygon
-%CPPSELF.%FUNCTION_NAME(%1.data(), %1.size(), %2);
+%CPPSELF.%FUNCTION_NAME(%1.constData(), %1.size(), %2);
 // @snippet qpainter-drawpolygon
 
+// @snippet qpainter-enter
+Py_INCREF(%PYSELF);
+pyResult = %PYSELF;
+// @snippet qpainter-enter
+
+// @snippet qpainter-exit
+%CPPSELF.end();
+// @snippet qpainter-exit
+
 // @snippet qmatrix4x4
 // PYSIDE-795: All PySequences can be made iterable with PySequence_Fast.
 Shiboken::AutoDecRef seq(PySequence_Fast(%PYARG_1, "Can't turn into sequence"));
@@ -507,8 +733,8 @@ if (PySequence_Check(_key)) {
     if (PySequence_Fast_GET_SIZE(key.object()) == 2) {
         PyObject *posx = PySequence_Fast_GET_ITEM(key.object(), 0);
         PyObject *posy = PySequence_Fast_GET_ITEM(key.object(), 1);
-        Py_ssize_t x = PyInt_AsSsize_t(posx);
-        Py_ssize_t y = PyInt_AsSsize_t(posy);
+        Py_ssize_t x = PyLong_AsSsize_t(posx);
+        Py_ssize_t y = PyLong_AsSsize_t(posy);
         float ret = (*%CPPSELF)(x,y);
         return %CONVERTTOPYTHON[float](ret);
     }
@@ -542,6 +768,12 @@ if (!PyTuple_SetItem(empty, 0, PyList_New(0))) {
 }
 // @snippet qguiapplication-2
 
+// @snippet qguiapplication-setoverridecursor
+auto *cppResult = new QtGuiHelper::QOverrideCursorGuard();
+%PYARG_0 = %CONVERTTOPYTHON[QtGuiHelper::QOverrideCursorGuard*](cppResult);
+Shiboken::Object::getOwnership(%PYARG_0); // Ensure the guard is removed
+// @snippet qguiapplication-setoverridecursor
+
 // @snippet qscreen-grabWindow
 WId id = %1;
 %RETURN_TYPE retval = %CPPSELF.%FUNCTION_NAME(id, %2, %3, %4, %5);
@@ -554,6 +786,10 @@ WId id = %1;
 %PYARG_0 = %CONVERTTOPYTHON[%RETURN_TYPE](retval);
 // @snippet qwindow-fromWinId
 
+// @snippet set-qtkey-shortcut
+%CPPSELF.%FUNCTION_NAME(QKeyCombination(%1));
+// @snippet set-qtkey-shortcut
+
 // @snippet qshortcut-1
 %0 = new %TYPE(%1, %2);
 // @snippet qshortcut-1
@@ -611,6 +847,20 @@ else
 %PYARG_0 = %CONVERTTOPYTHON[int](cppResult);
 // @snippet qdrag-exec-arg2
 
+// @snippet qregion-len
+return %CPPSELF.rectCount();
+// @snippet qregion-len
+
+// @snippet qregion-getitem
+if (_i < 0 || _i >= %CPPSELF.rectCount()) {
+    PyErr_SetString(PyExc_IndexError, "index out of bounds");
+    return nullptr;
+}
+
+const QRect cppResult = *(%CPPSELF.cbegin() + _i);
+return %CONVERTTOPYTHON[QRect](cppResult);
+// @snippet qregion-getitem
+
 /*********************************************************************
  * CONVERSIONS
  ********************************************************************/
